#!/bin/bash

function update_confile()
{
    # check whether the key:value pair is already in the config
    if grep -q "^${1}:.*${2}" "$UNIPI_LTE_CONFIG"; then
        # yes it is, nothing to update
        echo "The key \"$1\" with value $2 is already present"
        return 0
    fi

    # the key:value pair is not present or active, we should change the config

    # check whether the key is there, even commented
    if grep -q "^;*${1}:" "$UNIPI_LTE_CONFIG"; then
        # the key is there, we will mangle its value and leave the comment, if there is any
        sed -i "s/^;*${1}:[^;]*/${1}: ${2} /I" "$UNIPI_LTE_CONFIG"
        echo "The key $1 is already present, but with different value or commented out => changing"
    else
        # the key is not present at all, add it after start of the [MAIN] section
        sed -i "/\\[MAIN\\]/a ${1}: ${2}" "$UNIPI_LTE_CONFIG"
        echo "The key $1 is not present at all => adding"
    fi

    return 1
}

function force_comment()
{
    # if the parameter is uncommented, comment it
    echo "Forcing comment on $1"
    sed -i "s/\\(^$1:.*\\)/;\\1/I" "$UNIPI_LTE_CONFIG"
}

function configure_gsm()
{
    #flag for checking whether some change in the config file happend
    changed=0
    enabled=0


    # if the LTE should be disabled, stop the service and disable it
    if [ "$enabled" == "0" ]; then
        #check whether the service is active
        if [ "$(systemctl is-active unipi-lte)" == "active" ]; then
            echo -n "LTE daemon is running, trying to stop it... "
            if ! systemctl stop unipi-lte; then
                echo "FAILED"
            else
                echo "Ok"
            fi
        else
            echo "LTE daemon is not running"
        fi

        # check whether the service is enabled
        if [ "$(systemctl is-enabled unipi-lte)" == "enabled" ]; then
            echo -n "LTE daemon is enabled, trying to disable it... "
            if ! systemctl disable unipi-lte; then
                echo "FAILED"
            else
                echo "Ok"
            fi
        else
            echo "LTE daemon is already disabled"
        fi
    else
        # LTE should be on, generate the interfaces.d file
        echo "Generating wwan0 interface configuration to $TMP_INTERFACES_D/wwan0"
        echo "allow-hotplug wwan0" > "$TMP_INTERFACES_D/wwan0"
        echo "iface wwan0 inet dhcp" >> "$TMP_INTERFACES_D/wwan0"

        # the LTE daemon should be running
        if [ "$(systemctl is-enabled unipi-lte)" == "disabled" ]; then
            # daemon is disabled, enable it first
            echo -n "LTE daemon is disabled, trying to enabled it... "
            if ! systemctl enable unipi-lte; then
                echo "FAILED"
            else
                echo "Ok"
            fi
        fi
        # daemon is enabled, check if it is running
        if [ "$(systemctl is-active unipi-lte)" == "active" ]; then
            # it's running, if some change happend, restart the unipi-lte
            if [ "$changed" == "1" ]; then
                echo -n "Restarting unipi-lte daemon..."
                if ! systemctl restart unipi-lte; then
                    echo "FAILED"
                else
                    echo "Ok"
                fi
            else
                echo "No change in configuration, no need to restart the LTE deamon"
            fi
        else
            # not running, just start it    
            echo -n "LTE daemon is stopped, trying to start it... "
            if ! systemctl start unipi-lte; then
                echo "FAILED"
            else
                echo "Ok"
            fi
        fi
        # end of "already enabled, start or restart it" section
    fi
}
